@@ -34,7 +34,7 @@ class SensePushConsumer(object):
             self.insert(database=database, table=table, data=data)
         elif action == PUSH_ACTION_UPDATE:
             after = data.get('after')
-            if after:
+            if after and type(after) == dict:
                 data = after
             self.update(database=database, table=table, data=data)
         elif action == PUSH_ACTION_DELETE:
