@@ -108,12 +108,13 @@ class DjangoPushDataHandler(object):
         except Exception as ex:
             self.close_model_connection()
             sd.log_exception(ex)
-            sd.log_error("execption for table={0} data2={1} action={2}".format(table,  data2, action))
+            sd.log_error("execption for table={0} data2={1} action={2}".format(table, data2, action))
+            sd.sleep(1)
             raise ex
 
     def update(self, database, table, data):
         after = data.get('after')
-        if after:
+        if after and type(after) == dict:
             data = after
         self._insert0(database, table, data, "update")
         self.callback_handle(PUSH_ACTION_UPDATE, database, table, data)
@@ -171,7 +172,8 @@ class DjangoPushDataHandler(object):
         except Exception as ex:
             self.close_model_connection()
             sd.log_exception(ex)
-            sd.log_error("delete error table={} data={}".format(table,data))
+            sd.log_error("delete error table={} data={}".format(table, data))
+            sd.sleep(1)
 
     def callback_handle(self, action, database, table, data):
         pass
