@@ -59,7 +59,9 @@ class SensePushManager(object):
             for item in items:
                 for key in item.keys():
                     value = item[key]
-                    if type(value) == datetime.datetime or type(value) == datetime.date:
+                    if type(value) == datetime.date:
+                        item[key] = value.strftime("%Y-%m-%d")
+                    elif type(value) == datetime.datetime:
                         item[key] = str(value)
                 handler.insert_data(item)
                 if primary_key:
